@@ -1,7 +1,7 @@
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(
     paste(
-      "Thank you for using TwoDcDAPSA (PJC Calculator).",
+      "Thank you for using TwoDcDAPSA.",
       "Ranges used for cDAPSA inputs:",
       " - Swollen Joint Count (0-66)",
       " - Tender Joint Count  (0-68)",
